PALM-meteo: palmmeteo.library.AssimCycle Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Protected Member Functions | List of all members
palmmeteo.library.AssimCycle Class Reference

## Public Member Functions
| __init__ (self, cfgsect)

## Public Attributes
| cycle_int
| is_selected
| cycle_ref

## Protected Member Functions
| _is_selected_interval (self, cycle_dt)
| _is_selected_single (self, cycle_dt)
| _is_selected_all (self, cycle_dt)

## Detailed Description

    List of selected assimilation cycles based on configuration

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo.library.AssimCycle.__init__ | ( |  | self,
|  |  | cfgsect
| ) |  |

## Member Function Documentation

## ◆ _is_selected_all()

palmmeteo.library.AssimCycle._is_selected_all | ( |  | self,
|  |  | cycle_dt
| ) |  |
| protected

    Test whether the cycle is among the selected cycles

## ◆ _is_selected_interval()

palmmeteo.library.AssimCycle._is_selected_interval | ( |  | self,
|  |  | cycle_dt
| ) |  |
| protected

    Test whether the cycle is among the selected cycles

## ◆ _is_selected_single()

palmmeteo.library.AssimCycle._is_selected_single | ( |  | self,
|  |  | cycle_dt
| ) |  |
| protected

    Test whether the cycle is among the selected cycles

## Member Data Documentation

## ◆ cycle_int

palmmeteo.library.AssimCycle.cycle_int

## ◆ cycle_ref

palmmeteo.library.AssimCycle.cycle_ref

## ◆ is_selected

palmmeteo.library.AssimCycle.is_selected

The documentation for this class was generated from the following file:

- palmmeteo/library.py